@@ -151,7 +151,7 @@ class CollectionVersion(Content):
 
     # Foreign Key Fields
     collection = models.ForeignKey(
-        Collection, on_delete=models.CASCADE, related_name="versions", editable=False
+        Collection, on_delete=models.PROTECT, related_name="versions", editable=False
     )
     tags = models.ManyToManyField(Tag, editable=False)
 
@@ -308,12 +308,45 @@ class AnsibleRepository(Repository):
     REMOTE_TYPES = [RoleRemote, CollectionRemote]
 
     last_synced_metadata_time = models.DateTimeField(null=True)
+    keyring = models.FilePathField(path="/etc/pulp/certs/", recursive=True, blank=True)
 
     class Meta:
         default_related_name = "%(app_label)s_%(model_name)s"
 
         permissions = (("modify_ansible_repo_content", "Can modify ansible repository content"),)
 
+    def finalize_new_version(self, new_version):
+        """Finalize repo version."""
+        removed_collection_versions = new_version.removed(
+            base_version=new_version.base_version
+        ).filter(pulp_type=CollectionVersion.get_pulp_type())
+
+        # Remove any deprecated and signature content associated with the removed collection
+        # versions
+        for version in removed_collection_versions:
+            version = version.cast()
+
+            signatures = new_version.get_content(
+                content_qs=CollectionVersionSignature.objects.filter(signed_collection=version)
+            )
+            new_version.remove_content(signatures)
+
+            other_collection_versions = new_version.get_content(
+                content_qs=CollectionVersion.objects.filter(collection=version.collection)
+            )
+
+            # AnsibleCollectionDeprecated applies to all collection versions in a repository,
+            # so only remove it if there are no more collection versions for the specified
+            # collection present.
+            if not other_collection_versions.exists():
+                deprecations = new_version.get_content(
+                    content_qs=AnsibleCollectionDeprecated.objects.filter(
+                        namespace=version.namespace, name=version.name
+                    )
+                )
+
+                new_version.remove_content(deprecations)
+
 
 class AnsibleDistribution(Distribution):
     """
